@@ -29,8 +29,7 @@ use Math::MatrixReal;
 use MCE::Loop;
 use SQL::Abstract::Classic;
 use SQL::Inserter;
-use Sys::Info;
-use Sys::Info::Constants qw( :device_cpu );
+use System::Info;
 use Text::Fuzzy;
 use Text::Levenshtein::Damerau::XS;
 
@@ -38,7 +37,7 @@ use Exporter 'import';
 our @EXPORT = qw(system_identity suite_run calc_scalability);
 our $datadir = dist_dir("Benchmark-DKbench");
 
-our $VERSION = '2.0_004';
+our $VERSION = '2.0_005';
 
 =head1 NAME
 
@@ -63,14 +62,28 @@ Benchmark::DKbench - Perl CPU Benchmark
 
 A Perl benchmark suite for general compute, created to evaluate the comparative
 performance of systems when running computationally intensive Perl (both pure Perl
-and XS) workloads. Runs single and multi-threaded and can be fully customized to
-the benchmarks that better suit your own scenario.
+and C/XS) workloads. It is a good overall indicator for real world generic CPU
+performance. It runs single and multi-threaded (easily scaling to hundreds of CPUs)
+and can be fully customized to run the benchmarks that better suit your own scenario.
 
-The only non-CPAN software required to install/run the suite is libjpeg (with
-headers) and a build environment (C compiler etc) for the XS/C modules.
-Other than that there are quite a few prerequisite CPAN libraries, as they are used
-for the various benchmarks, plus an optional one (L<BioPerl>, requires libxml on
-system) which enables a couple of extra benchmarks.
+=head1 INSTALLATION
+
+The only non-CPAN software required to install/run the suite is a build environment
+(i.e. C compiler, make etc.) for the C/XS modules. On some well known Linux package
+managers you can do:
+
+ # Debian/Ubuntu etc
+ sudo apt install build-essential
+
+ # CentOS/Redhat
+ sudo yum install gcc gcc-c++ kernel-devel make
+
+After that, you can use L<App::cpanminus> to install the benchmark suite:
+
+ cpanm -n Benchmark::DKbench
+
+See the C<setup_dkbench> script below for more on the installation of a couple of
+optional benchmarks and standardizing your benchmarking environment.
 
 =head1 SCRIPTS
 
@@ -96,7 +109,7 @@ options to control number of threads, iterations, which benchmarks to run etc:
  --quick,       -q     : Quick benchmark run (implies -t).
  --no_mce              : Do not run under MCE::Loop (implies -j 1).
  --skip_bio            : Skip BioPerl benchmarks.
- --skip_timep          : Skip Time::Piece benchmark (see benchmark details on why).
+ --skip_timep          : Skip Time::Piece benchmark (see benchmark details).
  --skip_prove          : Skip Moose prove benchmark.
  --bio_codons          : Run optional BioPerl Codons benchmark (does not scale well).
  --sleep <i>           : Sleep for <i> secs after each benchmark.
@@ -128,8 +141,8 @@ there is an option to disable it, which forces a single-thread run.
 Simple installer to check/get the reference versions of CPAN modules and download
 the Genbank data file required for the BioPerl benchmarks of the DKbench suite.
 
-It assumes that you have some software already installed (e.g. C<cpanm>), try
-C<setup_dkbench --help> for more details on that.
+It assumes that you have some software already installed (see INSTALLATION above),
+try C<setup_dkbench --help> will give you more details.
 
  setup_dkbench [--force --sudo --test --data=s --help]
 
@@ -304,7 +317,7 @@ sub benchmark_list {
         'Digest'           => ['4b69f6cf0f53cbf6c3444f2f767dd21d', 4.513, \&bench_digest, 50, 250],
         'Encode'           => ['PASS 1025',                        5.725, \&bench_encode, 40, 120],
         'HTML::FormatText' => ['8c2589f0a5276252805e11301fc2ab56', 4.756, \&bench_formattext, 4, 10],
-        'Imager'           => ['8829cb3703e884054eb025496f336c63', 6.783, \&bench_imager, 4, 16],
+        'Imager'           => ['8829cb3703e884054eb025496f336c63', 6.792, \&bench_imager, 4, 16],
         'JSON::XS'         => ['PASS',                             5.388, \&bench_json, 600, 2200],
         'Math::DCT'        => ['766e3bfd7a2276f452bb3d1bd21939bc', 7.147, \&bench_dct, 25000, 100_000],
         'Math::MatrixReal' => ['4606231b1309fb21ae1223fa0043fd76', 4.293, \&bench_matrixreal, 200, 650],
@@ -319,29 +332,23 @@ sub benchmark_list {
 }
 
 sub system_identity {
-    my $info  = Sys::Info->new;
-    my $cpu   = $info->device( 'CPU' );
-    my @data  = $cpu->identify;
-    my $speed = $cpu->speed ? " @ ".(int($cpu->speed+0.5))."MHz" : '';
-    my $cores = $cpu->count || 1;
-    my $ht    = $cpu->ht ?  $cpu->ht == $cores ? " (h-threads)" : " (".$cpu->ht." threads)" : '';
-    my $arch  = $data[0]->{architecture} ? " ($data[0]->{architecture})" : '';
-    my $model = $data[0]->{chip_name} || $data[0]->{name} || $data[0]->{model} || 'Unknown';
-    my $os    = $info->os;
-    my $osn   = eval{$os->name(long => 1)} || $^O;
-    if ($^O =~ /darwin/ && $model =~ /^Mac|Unknown/) {
+    my $info  = System::Info->sysinfo_hash;
+    my $model = $info->{cpu};
+    my $cores = $info->{cpu_cores} || 1;
+    my $arch  = $info->{cpu_type} || '';
+    my $osn   = $info->{distro} || $info->{os} || $^O;
+    $arch = " ($arch)" if $arch;
+    if ($^O =~ /darwin/ && $model =~ /^Mac|nknown/) {
         my $brand = `sysctl -a |grep brand`;
         if ($brand =~ /brand_string: (.*)/) {
             $model = $1;
         }
     }
-    $speed = '' if $model =~ /@|GHz|MHz/;
-
     print "------------ Software ------------\nDKbench v$VERSION\n";
     print "Perl $^V\n";
     print "OS: $osn\n------------ Hardware ------------\n";
-    print "CPU type: $model$speed$arch\n";
-    print "Cores: $cores$ht\n".("-"x34)."\n";
+    print "CPU type: $model$arch\n";
+    print "Cores: $cores\n".("-"x34)."\n";
 
     return $cores;
 };
@@ -357,7 +364,7 @@ sub suite_run {
     MCE::Loop::init {
         max_workers => $opt->{threads},
         chunk_size  => 1,
-    };
+    } unless $opt->{no_mce};
 
     foreach (1..$opt->{iter}) {
         print "Iteration $_ of $opt->{iter}...\n" if $opt->{iter} > 1;
@@ -664,12 +671,12 @@ sub bench_imager {
     my $d    = Digest->new("MD5");
 
     my $data;
-    open (my $fh, '<:raw', catfile($datadir,'M31.jpg')) or die $!;
+    open (my $fh, '<:raw', catfile($datadir,'M31.bmp')) or die $!;
     read($fh, $data, -s $fh);
     close($fh);
 
     foreach (1..$iter) {
-        my $img = Imager->new(data=>$data) or die Imager->errstr();
+        my $img = Imager->new(data=>$data, type=>'bmp') or die Imager->errstr();
         my $thumb = $img->scale(scalefactor=>.3);
         my $newimg = $img->scale(scalefactor=>1.15);
         $newimg->filter(type=>'autolevels');
